{
    "$graph": [
        {
            "class": "Workflow",
            "label": "Apply filters to VCF file",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "id": "#main/do_cle_vcf_filter"
                },
                {
                    "type": "float",
                    "id": "#main/filter_gnomADe_maximum_population_allele_frequency"
                },
                {
                    "type": "float",
                    "id": "#main/filter_mapq0_threshold"
                },
                {
                    "type": "int",
                    "id": "#main/filter_minimum_depth"
                },
                {
                    "type": "float",
                    "id": "#main/filter_somatic_llr_normal_contamination_rate"
                },
                {
                    "type": "float",
                    "id": "#main/filter_somatic_llr_threshold"
                },
                {
                    "type": "float",
                    "id": "#main/filter_somatic_llr_tumor_purity"
                },
                {
                    "type": "string",
                    "id": "#main/gnomad_field_name"
                },
                {
                    "type": "string",
                    "id": "#main/normal_sample_name"
                },
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "id": "#main/reference"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#main/tumor_bam"
                },
                {
                    "type": "string",
                    "id": "#main/tumor_sample_name"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "doc": "An optional VCF with variants that will be flagged as 'VALIDATED' if found in this pipeline's main output VCF",
                    "id": "#main/validated_variants"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#main/vcf"
                }
            ],
            "steps": [
                {
                    "run": "#filter_known_variants.cwl",
                    "in": [
                        {
                            "source": "#main/validated_variants",
                            "id": "#main/filter_known_variants/validated_variants"
                        },
                        {
                            "source": "#main/vcf",
                            "id": "#main/filter_known_variants/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_known_variants/validated_annotated_vcf"
                    ],
                    "id": "#main/filter_known_variants"
                },
                {
                    "run": "#filter_vcf_cle.cwl",
                    "in": [
                        {
                            "source": "#main/do_cle_vcf_filter",
                            "id": "#main/filter_vcf_cle/filter"
                        },
                        {
                            "source": "#main/filter_vcf_mapq0/mapq0_filtered_vcf",
                            "id": "#main/filter_vcf_cle/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_cle/cle_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_cle"
                },
                {
                    "run": "#filter_vcf_depth.cwl",
                    "in": [
                        {
                            "source": "#main/filter_minimum_depth",
                            "id": "#main/filter_vcf_depth/minimum_depth"
                        },
                        {
                            "source": [
                                "#main/normal_sample_name",
                                "#main/tumor_sample_name"
                            ],
                            "linkMerge": "merge_flattened",
                            "id": "#main/filter_vcf_depth/sample_names"
                        },
                        {
                            "source": "#main/filter_vcf_cle/cle_filtered_vcf",
                            "id": "#main/filter_vcf_depth/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_depth/depth_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_depth"
                },
                {
                    "run": "#filter_vcf_custom_allele_freq.cwl",
                    "in": [
                        {
                            "source": "#main/gnomad_field_name",
                            "id": "#main/filter_vcf_gnomADe_allele_freq/field_name"
                        },
                        {
                            "source": "#main/filter_gnomADe_maximum_population_allele_frequency",
                            "id": "#main/filter_vcf_gnomADe_allele_freq/maximum_population_allele_frequency"
                        },
                        {
                            "source": "#main/filter_known_variants/validated_annotated_vcf",
                            "id": "#main/filter_vcf_gnomADe_allele_freq/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_gnomADe_allele_freq/filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_gnomADe_allele_freq"
                },
                {
                    "run": "#filter_vcf_mapq0.cwl",
                    "in": [
                        {
                            "source": "#main/reference",
                            "id": "#main/filter_vcf_mapq0/reference"
                        },
                        {
                            "source": "#main/filter_mapq0_threshold",
                            "id": "#main/filter_vcf_mapq0/threshold"
                        },
                        {
                            "source": "#main/tumor_bam",
                            "id": "#main/filter_vcf_mapq0/tumor_bam"
                        },
                        {
                            "source": "#main/filter_vcf_gnomADe_allele_freq/filtered_vcf",
                            "id": "#main/filter_vcf_mapq0/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_mapq0/mapq0_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_mapq0"
                },
                {
                    "run": "#filter_vcf_somatic_llr.cwl",
                    "in": [
                        {
                            "source": "#main/filter_somatic_llr_normal_contamination_rate",
                            "id": "#main/filter_vcf_somatic_llr/normal_contamination_rate"
                        },
                        {
                            "source": "#main/normal_sample_name",
                            "id": "#main/filter_vcf_somatic_llr/normal_sample_name"
                        },
                        {
                            "source": "#main/filter_somatic_llr_threshold",
                            "id": "#main/filter_vcf_somatic_llr/threshold"
                        },
                        {
                            "source": "#main/filter_somatic_llr_tumor_purity",
                            "id": "#main/filter_vcf_somatic_llr/tumor_purity"
                        },
                        {
                            "source": "#main/tumor_sample_name",
                            "id": "#main/filter_vcf_somatic_llr/tumor_sample_name"
                        },
                        {
                            "source": "#main/filter_vcf_depth/depth_filtered_vcf",
                            "id": "#main/filter_vcf_somatic_llr/vcf"
                        }
                    ],
                    "out": [
                        "#main/filter_vcf_somatic_llr/somatic_llr_filtered_vcf"
                    ],
                    "id": "#main/filter_vcf_somatic_llr"
                },
                {
                    "run": "#staged_rename.cwl",
                    "in": [
                        {
                            "valueFrom": "annotated_filtered.vcf",
                            "id": "#main/set_final_vcf_name/name"
                        },
                        {
                            "source": "#main/filter_vcf_somatic_llr/somatic_llr_filtered_vcf",
                            "id": "#main/set_final_vcf_name/original"
                        }
                    ],
                    "out": [
                        "#main/set_final_vcf_name/replacement"
                    ],
                    "id": "#main/set_final_vcf_name"
                }
            ],
            "id": "#main",
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/set_final_vcf_name/replacement",
                    "id": "#main/filtered_vcf"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Adds an INFO tag (VALIDATED) flagging variants in the pipeline vcf present in a previously validated vcf file",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/bcftools-cwl:1.12"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entryname": "annotate.sh",
                            "entry": "set -eou pipefail\n\nPIPELINE_VCF=\"$1\"\n\nif [ \"$#\" -eq 2 ]; then\n    VALIDATED_VCF=\"$2\"\n    /opt/bcftools/bin/bcftools view -f PASS -Oz -o pass_filtered_validated_variants.vcf.gz $VALIDATED_VCF\n    /opt/bcftools/bin/bcftools index -t pass_filtered_validated_variants.vcf.gz\n    /opt/bcftools/bin/bcftools annotate -Oz -o validated_annotated_pipeline_variants.vcf.gz -a pass_filtered_validated_variants.vcf.gz -m 'VALIDATED' $PIPELINE_VCF\n    /opt/bcftools/bin/bcftools index -t validated_annotated_pipeline_variants.vcf.gz\nelif [ \"$#\" -eq 1 ]; then\n    cp $PIPELINE_VCF validated_annotated_pipeline_variants.vcf.gz\n    cp $PIPELINE_VCF.tbi validated_annotated_pipeline_variants.vcf.gz.tbi\nelse\n    exit 1\nfi\n"
                        }
                    ]
                }
            ],
            "baseCommand": [
                "/bin/bash",
                "annotate.sh"
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "A vcf of previously discovered variants to be marked in the pipeline vcf; if not provided, this tool does nothing but rename the input vcf",
                    "id": "#filter_known_variants.cwl/validated_variants"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "inputBinding": {
                        "position": 1
                    },
                    "doc": "Each variant in this file that is also in the validated vcf file (if supplied) will be marked with a VALIDATED flag in its INFO field",
                    "id": "#filter_known_variants.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "validated_annotated_pipeline_variants.vcf.gz"
                    },
                    "secondaryFiles": [
                        ".tbi"
                    ],
                    "id": "#filter_known_variants.cwl/validated_annotated_vcf"
                }
            ],
            "id": "#filter_known_variants.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "cle_annotated_vcf_filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/docm_and_coding_indel_selection.pl"
            ],
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/cle:v1.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "arguments": [
                "$(inputs.vcf.path)",
                "$(runtime.outdir)"
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "inputBinding": {
                        "prefix": "filter",
                        "position": 1
                    },
                    "id": "#filter_vcf_cle.cwl/filter"
                },
                {
                    "type": "File",
                    "id": "#filter_vcf_cle.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated_filtered.vcf"
                    },
                    "id": "#filter_vcf_cle.cwl/cle_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_cle.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Custom allele frequency filter",
            "baseCommand": [
                "/usr/bin/perl",
                "/usr/bin/vcf_check.pl"
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/vep_helper-cwl:vep_101.0_v1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.vcf.path)"
                },
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                },
                "/usr/bin/perl",
                "/opt/vep/src/ensembl-vep/filter_vep",
                "--format",
                "vcf",
                "-o",
                {
                    "valueFrom": "$(runtime.outdir)/annotated.af_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#filter_vcf_custom_allele_freq.cwl/field_name"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "valueFrom": "${\n    return [\n        \"--filter\",\n        [\n            inputs.field_name, \"<\", inputs.maximum_population_allele_frequency,\n            \"or not\", inputs.field_name\n        ].join(\" \")\n    ]\n}\n",
                        "position": 2
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/maximum_population_allele_frequency"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 1
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "annotated.af_filtered.vcf"
                    },
                    "id": "#filter_vcf_custom_allele_freq.cwl/filtered_vcf"
                }
            ],
            "id": "#filter_vcf_custom_allele_freq.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter variants at sites below a given sequence depth in each sample",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/depth-filter:0.1.2"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "/opt/conda/bin/python3",
                "/usr/bin/depth_filter.py"
            ],
            "arguments": [
                {
                    "valueFrom": "$(runtime.outdir)/depth_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "inputBinding": {
                        "prefix": "--minimum_depth",
                        "position": -3
                    },
                    "id": "#filter_vcf_depth.cwl/minimum_depth"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "string"
                    },
                    "inputBinding": {
                        "itemSeparator": ",",
                        "position": -1
                    },
                    "id": "#filter_vcf_depth.cwl/sample_names"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#filter_vcf_depth.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "depth_filtered.vcf"
                    },
                    "id": "#filter_vcf_depth.cwl/depth_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_depth.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "filter vcf for variants with high percentage of mapq0 reads",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/mapq0-filter:v0.3.1"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "tmpdirMin": 10000
                }
            ],
            "arguments": [
                "/bin/bash",
                "/usr/bin/mapq0_vcf_filter.sh",
                {
                    "valueFrom": "$(runtime.outdir)/mapq_filtered.vcf.gz"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "string",
                        "File"
                    ],
                    "secondaryFiles": [
                        ".fai",
                        "^.dict"
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#filter_vcf_mapq0.cwl/reference"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "position": 4
                    },
                    "id": "#filter_vcf_mapq0.cwl/threshold"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "secondaryFiles": [
                        ".bai"
                    ],
                    "id": "#filter_vcf_mapq0.cwl/tumor_bam"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#filter_vcf_mapq0.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "mapq_filtered.vcf.gz"
                    },
                    "id": "#filter_vcf_mapq0.cwl/mapq0_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_mapq0.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "use the binomial/llr somatic filter to weed out low confidence variants",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "mgibio/somatic-llr-filter:v0.4.3"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000
                }
            ],
            "baseCommand": [
                "/opt/conda/bin/python3",
                "/usr/bin/somatic_llr_filter.py"
            ],
            "arguments": [
                "--overwrite",
                {
                    "valueFrom": "$(runtime.outdir)/somatic_llr_filtered.vcf"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--normal-contamination-rate",
                        "position": -5
                    },
                    "doc": "fraction of tumor present in the normal sample (range 0 to 1) - default 0",
                    "id": "#filter_vcf_somatic_llr.cwl/normal_contamination_rate"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--normal-sample-name"
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/normal_sample_name"
                },
                {
                    "type": "float",
                    "inputBinding": {
                        "prefix": "--llr-threshold",
                        "position": -2
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/threshold"
                },
                {
                    "type": [
                        "null",
                        "float"
                    ],
                    "inputBinding": {
                        "prefix": "--tumor-purity",
                        "position": -4
                    },
                    "doc": "tumor cellularity fraction (range 0 to 1) - default 1",
                    "id": "#filter_vcf_somatic_llr.cwl/tumor_purity"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--tumor-sample-name",
                        "position": -3
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/tumor_sample_name"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/vcf"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "somatic_llr_filtered.vcf"
                    },
                    "id": "#filter_vcf_somatic_llr.cwl/somatic_llr_filtered_vcf"
                }
            ],
            "id": "#filter_vcf_somatic_llr.cwl"
        },
        {
            "class": "CommandLineTool",
            "label": "Staged Renamer",
            "doc": "Renames a file by staging and then `mv`ing it.  A workaround for workflow engines that don't support rename.cwl.  If running in cwltool, use the other one instead.",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 4000,
                    "coresMin": 1
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "ubuntu:bionic"
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.original)"
                    ]
                }
            ],
            "baseCommand": [
                "/bin/mv"
            ],
            "arguments": [
                "$(inputs.original.basename)",
                "$(inputs.name)"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#staged_rename.cwl/name"
                },
                {
                    "type": "File",
                    "id": "#staged_rename.cwl/original"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.name)"
                    },
                    "id": "#staged_rename.cwl/replacement"
                }
            ],
            "id": "#staged_rename.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
